@@ -73,9 +73,12 @@ def {m}(self, new_val):
 			
 	def review(self): reviewers.review(self)
 	def make_string(self): self.string = reviewers.make_string(self)
-	def edit(self): editors.edit(self) 
+	def edit(self):
+		editors.edit(self) 
+		self.make_string()
 	def edit_metadata(self):
 		subprocess.run(['vim',self.path/'metadata.json'])
+		self.load_metadata()
 		self.make_string()
 	def schedule(self): schedulers.schedule(self) 
 
